import { Http,Util } from '@/utils';
import EntityService from '../entity-service';
import GenratePersonFileLogic from '@/service/pim-person/genrate-person-file-logic';
import GetJTLXRDHLogic from '@/service/pim-person/get-jtlxrdh-logic';
import PersonUpdateInfoLogic from '@/service/pim-person/person-update-info-logic';



/**
 * 人员信息服务对象基类
 *
 * @export
 * @class PimPersonServiceBase
 * @extends {EntityServie}
 */
export default class PimPersonServiceBase extends EntityService {

    /**
     * Creates an instance of  PimPersonServiceBase.
     * 
     * @param {*} [opts={}]
     * @memberof  PimPersonServiceBase
     */
    constructor(opts: any = {}) {
        super(opts);
    }

    /**
     * 初始化基础数据
     *
     * @memberof PimPersonServiceBase
     */
    public initBasicData(){
        this.APPLYDEKEY ='pimperson';
        this.APPDEKEY = 'pimpersonid';
        this.APPDENAME = 'pimpeople';
        this.APPDETEXT = 'pimpersonname';
        this.APPNAME = 'ehrpcm2';
        this.SYSTEMNAME = 'ehr_practice05';
    }

// 实体接口

    /**
     * Select接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PimPersonServiceBase
     */
    public async Select(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
            return Http.getInstance().get(`/pimpeople/${context.pimperson}/select`,isloading);
    }

    /**
     * Create接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PimPersonServiceBase
     */
    public async Create(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let masterData:any = {};
        let pcmjxsygzzjlmxesData:any = [];
        if(!Object.is(this.tempStorage.getItem(context.srfsessionkey+'_pcmjxsygzzjlmxes'),'undefined')){
            pcmjxsygzzjlmxesData = JSON.parse(this.tempStorage.getItem(context.srfsessionkey+'_pcmjxsygzzjlmxes') as any);
            if(pcmjxsygzzjlmxesData && pcmjxsygzzjlmxesData.length && pcmjxsygzzjlmxesData.length > 0){
                pcmjxsygzzjlmxesData.forEach((item:any) => {
                    if(item.srffrontuf){
                        if(Object.is(item.srffrontuf,"0")){
                            item.pcmjxsygzzjlmxid = null;
                        }
                        delete item.srffrontuf;
                    }
                });
            }
        }
        masterData.pcmjxsygzzjlmxes = pcmjxsygzzjlmxesData;
        let pcmxygzzjlmxesData:any = [];
        if(!Object.is(this.tempStorage.getItem(context.srfsessionkey+'_pcmxygzzjlmxes'),'undefined')){
            pcmxygzzjlmxesData = JSON.parse(this.tempStorage.getItem(context.srfsessionkey+'_pcmxygzzjlmxes') as any);
            if(pcmxygzzjlmxesData && pcmxygzzjlmxesData.length && pcmxygzzjlmxesData.length > 0){
                pcmxygzzjlmxesData.forEach((item:any) => {
                    if(item.srffrontuf){
                        if(Object.is(item.srffrontuf,"0")){
                            item.pcmxygzzjlmxid = null;
                        }
                        delete item.srffrontuf;
                    }
                });
            }
        }
        masterData.pcmxygzzjlmxes = pcmxygzzjlmxesData;
        let pimdistirbutionsData:any = [];
        if(!Object.is(this.tempStorage.getItem(context.srfsessionkey+'_pimdistirbutions'),'undefined')){
            pimdistirbutionsData = JSON.parse(this.tempStorage.getItem(context.srfsessionkey+'_pimdistirbutions') as any);
            if(pimdistirbutionsData && pimdistirbutionsData.length && pimdistirbutionsData.length > 0){
                pimdistirbutionsData.forEach((item:any) => {
                    if(item.srffrontuf){
                        if(Object.is(item.srffrontuf,"0")){
                            item.pimdistirbutionid = null;
                        }
                        delete item.srffrontuf;
                    }
                });
            }
        }
        masterData.pimdistirbutions = pimdistirbutionsData;
        let pimfaminfosData:any = [];
        if(!Object.is(this.tempStorage.getItem(context.srfsessionkey+'_pimfaminfos'),'undefined')){
            pimfaminfosData = JSON.parse(this.tempStorage.getItem(context.srfsessionkey+'_pimfaminfos') as any);
            if(pimfaminfosData && pimfaminfosData.length && pimfaminfosData.length > 0){
                pimfaminfosData.forEach((item:any) => {
                    if(item.srffrontuf){
                        if(Object.is(item.srffrontuf,"0")){
                            item.pimfaminfoid = null;
                        }
                        delete item.srffrontuf;
                    }
                });
            }
        }
        masterData.pimfaminfos = pimfaminfosData;
        let pcmydmxesData:any = [];
        if(!Object.is(this.tempStorage.getItem(context.srfsessionkey+'_pcmydmxes'),'undefined')){
            pcmydmxesData = JSON.parse(this.tempStorage.getItem(context.srfsessionkey+'_pcmydmxes') as any);
            if(pcmydmxesData && pcmydmxesData.length && pcmydmxesData.length > 0){
                pcmydmxesData.forEach((item:any) => {
                    if(item.srffrontuf){
                        if(Object.is(item.srffrontuf,"0")){
                            item.pcmydmxid = null;
                        }
                        delete item.srffrontuf;
                    }
                });
            }
        }
        masterData.pcmydmxes = pcmydmxesData;
        Object.assign(data,masterData);
        if(!data.srffrontuf || data.srffrontuf !== "1"){
            data[this.APPDEKEY] = null;
        }
        if(data.srffrontuf){
            delete data.srffrontuf;
        }
        let tempContext:any = JSON.parse(JSON.stringify(context));
        let res:any = await Http.getInstance().post(`/pimpeople`,data,isloading);
        this.tempStorage.setItem(tempContext.srfsessionkey+'_pcmjxsygzzjlmxes',JSON.stringify(res.data.pcmjxsygzzjlmxes));
        this.tempStorage.setItem(tempContext.srfsessionkey+'_pcmxygzzjlmxes',JSON.stringify(res.data.pcmxygzzjlmxes));
        this.tempStorage.setItem(tempContext.srfsessionkey+'_pimdistirbutions',JSON.stringify(res.data.pimdistirbutions));
        this.tempStorage.setItem(tempContext.srfsessionkey+'_pimfaminfos',JSON.stringify(res.data.pimfaminfos));
        this.tempStorage.setItem(tempContext.srfsessionkey+'_pcmydmxes',JSON.stringify(res.data.pcmydmxes));
        return res;
    }

    /**
     * Update接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PimPersonServiceBase
     */
    public async Update(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let masterData:any = {};
        let pcmjxsygzzjlmxesData:any = [];
        if(!Object.is(this.tempStorage.getItem(context.srfsessionkey+'_pcmjxsygzzjlmxes'),'undefined')){
            pcmjxsygzzjlmxesData = JSON.parse(this.tempStorage.getItem(context.srfsessionkey+'_pcmjxsygzzjlmxes') as any);
            if(pcmjxsygzzjlmxesData && pcmjxsygzzjlmxesData.length && pcmjxsygzzjlmxesData.length > 0){
                pcmjxsygzzjlmxesData.forEach((item:any) => {
                    if(item.srffrontuf){
                        if(Object.is(item.srffrontuf,"0")){
                            item.pcmjxsygzzjlmxid = null;
                        }
                        delete item.srffrontuf;
                    }
                });
            }
        }
        masterData.pcmjxsygzzjlmxes = pcmjxsygzzjlmxesData;
        let pcmxygzzjlmxesData:any = [];
        if(!Object.is(this.tempStorage.getItem(context.srfsessionkey+'_pcmxygzzjlmxes'),'undefined')){
            pcmxygzzjlmxesData = JSON.parse(this.tempStorage.getItem(context.srfsessionkey+'_pcmxygzzjlmxes') as any);
            if(pcmxygzzjlmxesData && pcmxygzzjlmxesData.length && pcmxygzzjlmxesData.length > 0){
                pcmxygzzjlmxesData.forEach((item:any) => {
                    if(item.srffrontuf){
                        if(Object.is(item.srffrontuf,"0")){
                            item.pcmxygzzjlmxid = null;
                        }
                        delete item.srffrontuf;
                    }
                });
            }
        }
        masterData.pcmxygzzjlmxes = pcmxygzzjlmxesData;
        let pimdistirbutionsData:any = [];
        if(!Object.is(this.tempStorage.getItem(context.srfsessionkey+'_pimdistirbutions'),'undefined')){
            pimdistirbutionsData = JSON.parse(this.tempStorage.getItem(context.srfsessionkey+'_pimdistirbutions') as any);
            if(pimdistirbutionsData && pimdistirbutionsData.length && pimdistirbutionsData.length > 0){
                pimdistirbutionsData.forEach((item:any) => {
                    if(item.srffrontuf){
                        if(Object.is(item.srffrontuf,"0")){
                            item.pimdistirbutionid = null;
                        }
                        delete item.srffrontuf;
                    }
                });
            }
        }
        masterData.pimdistirbutions = pimdistirbutionsData;
        let pimfaminfosData:any = [];
        if(!Object.is(this.tempStorage.getItem(context.srfsessionkey+'_pimfaminfos'),'undefined')){
            pimfaminfosData = JSON.parse(this.tempStorage.getItem(context.srfsessionkey+'_pimfaminfos') as any);
            if(pimfaminfosData && pimfaminfosData.length && pimfaminfosData.length > 0){
                pimfaminfosData.forEach((item:any) => {
                    if(item.srffrontuf){
                        if(Object.is(item.srffrontuf,"0")){
                            item.pimfaminfoid = null;
                        }
                        delete item.srffrontuf;
                    }
                });
            }
        }
        masterData.pimfaminfos = pimfaminfosData;
        let pcmydmxesData:any = [];
        if(!Object.is(this.tempStorage.getItem(context.srfsessionkey+'_pcmydmxes'),'undefined')){
            pcmydmxesData = JSON.parse(this.tempStorage.getItem(context.srfsessionkey+'_pcmydmxes') as any);
            if(pcmydmxesData && pcmydmxesData.length && pcmydmxesData.length > 0){
                pcmydmxesData.forEach((item:any) => {
                    if(item.srffrontuf){
                        if(Object.is(item.srffrontuf,"0")){
                            item.pcmydmxid = null;
                        }
                        delete item.srffrontuf;
                    }
                });
            }
        }
        masterData.pcmydmxes = pcmydmxesData;
        Object.assign(data,masterData);
            let res:any = await  Http.getInstance().put(`/pimpeople/${context.pimperson}`,data,isloading);
            this.tempStorage.setItem(context.srfsessionkey+'_pcmjxsygzzjlmxes',JSON.stringify(res.data.pcmjxsygzzjlmxes));
            this.tempStorage.setItem(context.srfsessionkey+'_pcmxygzzjlmxes',JSON.stringify(res.data.pcmxygzzjlmxes));
            this.tempStorage.setItem(context.srfsessionkey+'_pimdistirbutions',JSON.stringify(res.data.pimdistirbutions));
            this.tempStorage.setItem(context.srfsessionkey+'_pimfaminfos',JSON.stringify(res.data.pimfaminfos));
            this.tempStorage.setItem(context.srfsessionkey+'_pcmydmxes',JSON.stringify(res.data.pcmydmxes));
            return res;
    }

    /**
     * Remove接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PimPersonServiceBase
     */
    public async Remove(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
            return Http.getInstance().delete(`/pimpeople/${context.pimperson}`,isloading);
    }

    /**
     * Get接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PimPersonServiceBase
     */
    public async Get(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
            let res:any = await Http.getInstance().get(`/pimpeople/${context.pimperson}`,isloading);
            this.tempStorage.setItem(context.srfsessionkey+'_pcmjxsygzzjlmxes',JSON.stringify(res.data.pcmjxsygzzjlmxes));
            this.tempStorage.setItem(context.srfsessionkey+'_pcmxygzzjlmxes',JSON.stringify(res.data.pcmxygzzjlmxes));
            this.tempStorage.setItem(context.srfsessionkey+'_pimdistirbutions',JSON.stringify(res.data.pimdistirbutions));
            this.tempStorage.setItem(context.srfsessionkey+'_pimfaminfos',JSON.stringify(res.data.pimfaminfos));
            this.tempStorage.setItem(context.srfsessionkey+'_pcmydmxes',JSON.stringify(res.data.pcmydmxes));
            return res;
    }

    /**
     * GetDraft接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PimPersonServiceBase
     */
    public async GetDraft(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let res:any = await  Http.getInstance().get(`/pimpeople/getdraft`,isloading);
        res.data.pimperson = data.pimperson;
            this.tempStorage.setItem(context.srfsessionkey+'_pcmjxsygzzjlmxes',JSON.stringify(res.data.pcmjxsygzzjlmxes));
            this.tempStorage.setItem(context.srfsessionkey+'_pcmxygzzjlmxes',JSON.stringify(res.data.pcmxygzzjlmxes));
            this.tempStorage.setItem(context.srfsessionkey+'_pimdistirbutions',JSON.stringify(res.data.pimdistirbutions));
            this.tempStorage.setItem(context.srfsessionkey+'_pimfaminfos',JSON.stringify(res.data.pimfaminfos));
            this.tempStorage.setItem(context.srfsessionkey+'_pcmydmxes',JSON.stringify(res.data.pcmydmxes));
        return res;
    }

    /**
     * CheckKey接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PimPersonServiceBase
     */
    public async CheckKey(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
            return Http.getInstance().post(`/pimpeople/${context.pimperson}/checkkey`,data,isloading);
    }

    /**
     * FillPersonType接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PimPersonServiceBase
     */
    public async FillPersonType(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
            return Http.getInstance().post(`/pimpeople/${context.pimperson}/fillpersontype`,data,isloading);
    }

    /**
     * GeneratePersonFile接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PimPersonServiceBase
     */
    public async GeneratePersonFile(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
            return Http.getInstance().post(`/pimpeople/${context.pimperson}/generatepersonfile`,data,isloading);
    }

    /**
     * GetJTLXRDH接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PimPersonServiceBase
     */
    public async GetJTLXRDH(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let appLogic:GetJTLXRDHLogic = new GetJTLXRDHLogic({context:JSON.parse(JSON.stringify(context)),data:JSON.parse(JSON.stringify(data))});
        const result = await appLogic.onExecute(context,data,isloading?true:false);
        return {status:200,data:result};
    }

    /**
     * PersonUpdateInfo接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PimPersonServiceBase
     */
    public async PersonUpdateInfo(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
            return Http.getInstance().put(`/pimpeople/${context.pimperson}/personupdateinfo`,data,isloading);
    }

    /**
     * QRTX接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PimPersonServiceBase
     */
    public async QRTX(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
            return Http.getInstance().post(`/pimpeople/${context.pimperson}/qrtx`,data,isloading);
    }

    /**
     * Save接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PimPersonServiceBase
     */
    public async Save(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let masterData:any = {};
        let pcmjxsygzzjlmxesData:any = [];
        if(!Object.is(this.tempStorage.getItem(context.srfsessionkey+'_pcmjxsygzzjlmxes'),'undefined')){
            pcmjxsygzzjlmxesData = JSON.parse(this.tempStorage.getItem(context.srfsessionkey+'_pcmjxsygzzjlmxes') as any);
            if(pcmjxsygzzjlmxesData && pcmjxsygzzjlmxesData.length && pcmjxsygzzjlmxesData.length > 0){
                pcmjxsygzzjlmxesData.forEach((item:any) => {
                    if(item.srffrontuf){
                        if(Object.is(item.srffrontuf,"0")){
                            item.pcmjxsygzzjlmxid = null;
                        }
                        delete item.srffrontuf;
                    }
                });
            }
        }
        masterData.pcmjxsygzzjlmxes = pcmjxsygzzjlmxesData;
        let pcmxygzzjlmxesData:any = [];
        if(!Object.is(this.tempStorage.getItem(context.srfsessionkey+'_pcmxygzzjlmxes'),'undefined')){
            pcmxygzzjlmxesData = JSON.parse(this.tempStorage.getItem(context.srfsessionkey+'_pcmxygzzjlmxes') as any);
            if(pcmxygzzjlmxesData && pcmxygzzjlmxesData.length && pcmxygzzjlmxesData.length > 0){
                pcmxygzzjlmxesData.forEach((item:any) => {
                    if(item.srffrontuf){
                        if(Object.is(item.srffrontuf,"0")){
                            item.pcmxygzzjlmxid = null;
                        }
                        delete item.srffrontuf;
                    }
                });
            }
        }
        masterData.pcmxygzzjlmxes = pcmxygzzjlmxesData;
        let pimdistirbutionsData:any = [];
        if(!Object.is(this.tempStorage.getItem(context.srfsessionkey+'_pimdistirbutions'),'undefined')){
            pimdistirbutionsData = JSON.parse(this.tempStorage.getItem(context.srfsessionkey+'_pimdistirbutions') as any);
            if(pimdistirbutionsData && pimdistirbutionsData.length && pimdistirbutionsData.length > 0){
                pimdistirbutionsData.forEach((item:any) => {
                    if(item.srffrontuf){
                        if(Object.is(item.srffrontuf,"0")){
                            item.pimdistirbutionid = null;
                        }
                        delete item.srffrontuf;
                    }
                });
            }
        }
        masterData.pimdistirbutions = pimdistirbutionsData;
        let pimfaminfosData:any = [];
        if(!Object.is(this.tempStorage.getItem(context.srfsessionkey+'_pimfaminfos'),'undefined')){
            pimfaminfosData = JSON.parse(this.tempStorage.getItem(context.srfsessionkey+'_pimfaminfos') as any);
            if(pimfaminfosData && pimfaminfosData.length && pimfaminfosData.length > 0){
                pimfaminfosData.forEach((item:any) => {
                    if(item.srffrontuf){
                        if(Object.is(item.srffrontuf,"0")){
                            item.pimfaminfoid = null;
                        }
                        delete item.srffrontuf;
                    }
                });
            }
        }
        masterData.pimfaminfos = pimfaminfosData;
        let pcmydmxesData:any = [];
        if(!Object.is(this.tempStorage.getItem(context.srfsessionkey+'_pcmydmxes'),'undefined')){
            pcmydmxesData = JSON.parse(this.tempStorage.getItem(context.srfsessionkey+'_pcmydmxes') as any);
            if(pcmydmxesData && pcmydmxesData.length && pcmydmxesData.length > 0){
                pcmydmxesData.forEach((item:any) => {
                    if(item.srffrontuf){
                        if(Object.is(item.srffrontuf,"0")){
                            item.pcmydmxid = null;
                        }
                        delete item.srffrontuf;
                    }
                });
            }
        }
        masterData.pcmydmxes = pcmydmxesData;
        Object.assign(data,masterData);
            let res:any = await  Http.getInstance().post(`/pimpeople/${context.pimperson}/save`,data,isloading);
            this.tempStorage.setItem(context.srfsessionkey+'_pcmjxsygzzjlmxes',JSON.stringify(res.data.pcmjxsygzzjlmxes));
            this.tempStorage.setItem(context.srfsessionkey+'_pcmxygzzjlmxes',JSON.stringify(res.data.pcmxygzzjlmxes));
            this.tempStorage.setItem(context.srfsessionkey+'_pimdistirbutions',JSON.stringify(res.data.pimdistirbutions));
            this.tempStorage.setItem(context.srfsessionkey+'_pimfaminfos',JSON.stringify(res.data.pimfaminfos));
            this.tempStorage.setItem(context.srfsessionkey+'_pcmydmxes',JSON.stringify(res.data.pcmydmxes));
            return res;
    }

    /**
     * SynPerson接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PimPersonServiceBase
     */
    public async SynPerson(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
            return Http.getInstance().post(`/pimpeople/${context.pimperson}/synperson`,data,isloading);
    }

    /**
     * ToggleLeader接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PimPersonServiceBase
     */
    public async ToggleLeader(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
            return Http.getInstance().post(`/pimpeople/${context.pimperson}/toggleleader`,data,isloading);
    }

    /**
     * YZSFYZFP接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PimPersonServiceBase
     */
    public async YZSFYZFP(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
            return Http.getInstance().post(`/pimpeople/${context.pimperson}/yzsfyzfp`,data,isloading);
    }

    /**
     * FetchAuthPerson接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PimPersonServiceBase
     */
    public async FetchAuthPerson(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let tempData:any = JSON.parse(JSON.stringify(data));
        return Http.getInstance().get(`/pimpeople/fetchauthperson`,tempData,isloading);
    }

    /**
     * FetchBYLYG接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PimPersonServiceBase
     */
    public async FetchBYLYG(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let tempData:any = JSON.parse(JSON.stringify(data));
        return Http.getInstance().get(`/pimpeople/fetchbylyg`,tempData,isloading);
    }

    /**
     * FetchCurJHRY接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PimPersonServiceBase
     */
    public async FetchCurJHRY(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let tempData:any = JSON.parse(JSON.stringify(data));
        return Http.getInstance().get(`/pimpeople/fetchcurjhry`,tempData,isloading);
    }

    /**
     * FetchCurLeader接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PimPersonServiceBase
     */
    public async FetchCurLeader(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let tempData:any = JSON.parse(JSON.stringify(data));
        return Http.getInstance().get(`/pimpeople/fetchcurleader`,tempData,isloading);
    }

    /**
     * FetchCurOrgPerson接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PimPersonServiceBase
     */
    public async FetchCurOrgPerson(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let tempData:any = JSON.parse(JSON.stringify(data));
        return Http.getInstance().get(`/pimpeople/fetchcurorgperson`,tempData,isloading);
    }

    /**
     * FetchCurOrgPimperson接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PimPersonServiceBase
     */
    public async FetchCurOrgPimperson(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let tempData:any = JSON.parse(JSON.stringify(data));
        return Http.getInstance().get(`/pimpeople/fetchcurorgpimperson`,tempData,isloading);
    }

    /**
     * FetchDTXYG接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PimPersonServiceBase
     */
    public async FetchDTXYG(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let tempData:any = JSON.parse(JSON.stringify(data));
        return Http.getInstance().get(`/pimpeople/fetchdtxyg`,tempData,isloading);
    }

    /**
     * FetchDefault接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PimPersonServiceBase
     */
    public async FetchDefault(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let tempData:any = JSON.parse(JSON.stringify(data));
        return Http.getInstance().get(`/pimpeople/fetchdefault`,tempData,isloading);
    }

    /**
     * FetchGBHMC接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PimPersonServiceBase
     */
    public async FetchGBHMC(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let tempData:any = JSON.parse(JSON.stringify(data));
        return Http.getInstance().get(`/pimpeople/fetchgbhmc`,tempData,isloading);
    }

    /**
     * FetchGZDQGL接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PimPersonServiceBase
     */
    public async FetchGZDQGL(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let tempData:any = JSON.parse(JSON.stringify(data));
        return Http.getInstance().get(`/pimpeople/fetchgzdqgl`,tempData,isloading);
    }

    /**
     * FetchJLSSGR接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PimPersonServiceBase
     */
    public async FetchJLSSGR(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let tempData:any = JSON.parse(JSON.stringify(data));
        return Http.getInstance().get(`/pimpeople/fetchjlssgr`,tempData,isloading);
    }

    /**
     * FetchJXQKZZRY接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PimPersonServiceBase
     */
    public async FetchJXQKZZRY(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let tempData:any = JSON.parse(JSON.stringify(data));
        return Http.getInstance().get(`/pimpeople/fetchjxqkzzry`,tempData,isloading);
    }

    /**
     * FetchJXQYGCX接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PimPersonServiceBase
     */
    public async FetchJXQYGCX(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let tempData:any = JSON.parse(JSON.stringify(data));
        return Http.getInstance().get(`/pimpeople/fetchjxqygcx`,tempData,isloading);
    }

    /**
     * FetchKFPRY接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PimPersonServiceBase
     */
    public async FetchKFPRY(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let tempData:any = JSON.parse(JSON.stringify(data));
        return Http.getInstance().get(`/pimpeople/fetchkfpry`,tempData,isloading);
    }

    /**
     * FetchKGZRY接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PimPersonServiceBase
     */
    public async FetchKGZRY(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let tempData:any = JSON.parse(JSON.stringify(data));
        return Http.getInstance().get(`/pimpeople/fetchkgzry`,tempData,isloading);
    }

    /**
     * FetchKQJRYCX接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PimPersonServiceBase
     */
    public async FetchKQJRYCX(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let tempData:any = JSON.parse(JSON.stringify(data));
        return Http.getInstance().get(`/pimpeople/fetchkqjrycx`,tempData,isloading);
    }

    /**
     * FetchKTXYG接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PimPersonServiceBase
     */
    public async FetchKTXYG(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let tempData:any = JSON.parse(JSON.stringify(data));
        return Http.getInstance().get(`/pimpeople/fetchktxyg`,tempData,isloading);
    }

    /**
     * FetchKXZSYQKZZRYDS接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PimPersonServiceBase
     */
    public async FetchKXZSYQKZZRYDS(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let tempData:any = JSON.parse(JSON.stringify(data));
        return Http.getInstance().get(`/pimpeople/fetchkxzsyqkzzryds`,tempData,isloading);
    }

    /**
     * FetchKZJBDRY接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PimPersonServiceBase
     */
    public async FetchKZJBDRY(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let tempData:any = JSON.parse(JSON.stringify(data));
        return Http.getInstance().get(`/pimpeople/fetchkzjbdry`,tempData,isloading);
    }

    /**
     * FetchLTXSTAFF接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PimPersonServiceBase
     */
    public async FetchLTXSTAFF(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let tempData:any = JSON.parse(JSON.stringify(data));
        return Http.getInstance().get(`/pimpeople/fetchltxstaff`,tempData,isloading);
    }

    /**
     * FetchLZRYHMC接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PimPersonServiceBase
     */
    public async FetchLZRYHMC(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let tempData:any = JSON.parse(JSON.stringify(data));
        return Http.getInstance().get(`/pimpeople/fetchlzryhmc`,tempData,isloading);
    }

    /**
     * FetchREP_PERSONAGE接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PimPersonServiceBase
     */
    public async FetchREP_PERSONAGE(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let tempData:any = JSON.parse(JSON.stringify(data));
        return Http.getInstance().get(`/pimpeople/fetchrep_personage`,tempData,isloading);
    }

    /**
     * FetchREP_PERSONORGTYPE接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PimPersonServiceBase
     */
    public async FetchREP_PERSONORGTYPE(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let tempData:any = JSON.parse(JSON.stringify(data));
        return Http.getInstance().get(`/pimpeople/fetchrep_personorgtype`,tempData,isloading);
    }

    /**
     * FetchRYZT_30接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PimPersonServiceBase
     */
    public async FetchRYZT_30(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let tempData:any = JSON.parse(JSON.stringify(data));
        return Http.getInstance().get(`/pimpeople/fetchryzt_30`,tempData,isloading);
    }

    /**
     * FetchSELFHELPID接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PimPersonServiceBase
     */
    public async FetchSELFHELPID(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let tempData:any = JSON.parse(JSON.stringify(data));
        return Http.getInstance().get(`/pimpeople/fetchselfhelpid`,tempData,isloading);
    }

    /**
     * FetchSFHMD接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PimPersonServiceBase
     */
    public async FetchSFHMD(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let tempData:any = JSON.parse(JSON.stringify(data));
        return Http.getInstance().get(`/pimpeople/fetchsfhmd`,tempData,isloading);
    }

    /**
     * FetchSSTRERSONINFO接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PimPersonServiceBase
     */
    public async FetchSSTRERSONINFO(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let tempData:any = JSON.parse(JSON.stringify(data));
        return Http.getInstance().get(`/pimpeople/fetchsstrersoninfo`,tempData,isloading);
    }

    /**
     * FetchSYQKZZRY接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PimPersonServiceBase
     */
    public async FetchSYQKZZRY(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let tempData:any = JSON.parse(JSON.stringify(data));
        return Http.getInstance().get(`/pimpeople/fetchsyqkzzry`,tempData,isloading);
    }

    /**
     * FetchSYQYGCX接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PimPersonServiceBase
     */
    public async FetchSYQYGCX(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let tempData:any = JSON.parse(JSON.stringify(data));
        return Http.getInstance().get(`/pimpeople/fetchsyqygcx`,tempData,isloading);
    }

    /**
     * FetchSetAttRules接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PimPersonServiceBase
     */
    public async FetchSetAttRules(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let tempData:any = JSON.parse(JSON.stringify(data));
        return Http.getInstance().get(`/pimpeople/fetchsetattrules`,tempData,isloading);
    }

    /**
     * FetchSetSocArchives接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PimPersonServiceBase
     */
    public async FetchSetSocArchives(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let tempData:any = JSON.parse(JSON.stringify(data));
        return Http.getInstance().get(`/pimpeople/fetchsetsocarchives`,tempData,isloading);
    }

    /**
     * FetchTXGB接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PimPersonServiceBase
     */
    public async FetchTXGB(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let tempData:any = JSON.parse(JSON.stringify(data));
        return Http.getInstance().get(`/pimpeople/fetchtxgb`,tempData,isloading);
    }

    /**
     * FetchTXRYCX接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PimPersonServiceBase
     */
    public async FetchTXRYCX(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let tempData:any = JSON.parse(JSON.stringify(data));
        return Http.getInstance().get(`/pimpeople/fetchtxrycx`,tempData,isloading);
    }

    /**
     * FetchTitleUse接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PimPersonServiceBase
     */
    public async FetchTitleUse(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let tempData:any = JSON.parse(JSON.stringify(data));
        return Http.getInstance().get(`/pimpeople/fetchtitleuse`,tempData,isloading);
    }

    /**
     * FetchXMBRYCX接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PimPersonServiceBase
     */
    public async FetchXMBRYCX(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let tempData:any = JSON.parse(JSON.stringify(data));
        return Http.getInstance().get(`/pimpeople/fetchxmbrycx`,tempData,isloading);
    }

    /**
     * FetchXZKQRY接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PimPersonServiceBase
     */
    public async FetchXZKQRY(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let tempData:any = JSON.parse(JSON.stringify(data));
        return Http.getInstance().get(`/pimpeople/fetchxzkqry`,tempData,isloading);
    }

    /**
     * FetchYGXXGLY接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PimPersonServiceBase
     */
    public async FetchYGXXGLY(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let tempData:any = JSON.parse(JSON.stringify(data));
        return Http.getInstance().get(`/pimpeople/fetchygxxgly`,tempData,isloading);
    }

    /**
     * FetchYXZFPRYDS接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PimPersonServiceBase
     */
    public async FetchYXZFPRYDS(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let tempData:any = JSON.parse(JSON.stringify(data));
        return Http.getInstance().get(`/pimpeople/fetchyxzfpryds`,tempData,isloading);
    }
}